@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 module Roadie
   module Rails
     class AssetPipelineProvider
@@ -5,25 +7,41 @@ module Roadie
       attr_reader :pipeline
 
       def initialize(pipeline)
-        raise ArgumentError, "You need to pass a pipeline to initialize AssetPipelineProvider" unless pipeline
+        unless pipeline
+          raise(
+            ArgumentError,
+            "You need to pass a pipeline to initialize AssetPipelineProvider"
+          )
+        end
+
         super()
         @pipeline = pipeline
       end
 
       def find_stylesheet(name)
         if (asset = find_asset_in_pipeline(name))
-          Stylesheet.new("#{asset.pathname} (live compiled)", asset.to_s)
+          Stylesheet.new("#{filename(asset)} (live compiled)", asset.to_s)
         end
       end
 
       private
+
+      def filename(asset)
+        if asset.respond_to?(:filename) # sprockets 4 or later
+          asset.filename
+        else
+          asset.pathname
+        end
+      end
+
       def find_asset_in_pipeline(name)
         normalized_name = normalize_asset_name(name)
-        @pipeline[normalized_name] || @pipeline[remove_asset_digest(normalized_name)]
+        @pipeline[normalized_name] ||
+          @pipeline[remove_asset_digest(normalized_name)]
       end
 
       def normalize_asset_name(href)
-        remove_asset_prefix(href.split('?').first)
+        remove_asset_prefix(href.split("?").first)
       end
 
       DIGEST_PATTERN = /
@@ -36,7 +54,7 @@ module Roadie
       /x.freeze
 
       def remove_asset_digest(path)
-        path.gsub(DIGEST_PATTERN, '.')
+        path.gsub(DIGEST_PATTERN, ".")
       end
 
       def remove_asset_prefix(path)
